access_check_polarity

Function access_check_polarity 

pub fn access_check_polarity<'gcx>(
    gcx: Gcx<'gcx>,
    expr: &Expr<'_>,
    aliases: &HashSet<VariableId>,
) -> Option<bool>
Some(true) when expr holding means the caller is authorized, Some(false) when it means the caller is not authorized, None when expr is not an access check. An access check reads msg.sender/tx.origin (directly, through aliases or through a helper) and state (directly or through a helper).