stmts_before_placeholder

Function stmts_before_placeholder 

pub fn stmts_before_placeholder<'a, 'gcx>(
    stmts: &'a [Stmt<'gcx>],
    out: &mut Vec<&'a Stmt<'gcx>>,
) -> Option<()>
Collects the statements executed before the first placeholder of a modifier body, following nested blocks. Returns None when the placeholder is not reached unconditionally (e.g. it is inside an if, loop or try).